@@ -621,12 +621,7 @@ public class MediaPlayer extends VLCObject<MediaPlayer.Event> {
             mPlaying = false;
             mAudioReset = true;
         }
-        new Thread(new Runnable() {
-            @Override
-            public void run() {
-                nativeStop();
-            }
-        }).start();
+        nativeStop();
     }
 
     /**
