@@ -260,7 +260,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
 
         // Make sure the audio player will acquire a wake-lock while playing. If we don't do
         // that, the CPU might go to sleep while the song is playing, causing playback to stop.
-        PowerManager pm = (PowerManager) VLCApplication.getAppContext().getSystemService(Context.POWER_SERVICE);
+        final PowerManager pm = (PowerManager) VLCApplication.getAppContext().getSystemService(Context.POWER_SERVICE);
         mWakeLock = pm.newWakeLock(PowerManager.PARTIAL_WAKE_LOCK, TAG);
 
         updateHasWidget();
@@ -286,13 +286,12 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         filter.addAction(ACTION_CAR_MODE_EXIT);
         registerReceiver(mReceiver, filter);
 
-        boolean stealRemoteControl = mSettings.getBoolean("enable_steal_remote_control", false);
+        final boolean stealRemoteControl = mSettings.getBoolean("enable_steal_remote_control", false);
 
         if (stealRemoteControl) {
             /* Backward compatibility for API 7 */
             filter = new IntentFilter();
-            if (stealRemoteControl)
-                filter.setPriority(Integer.MAX_VALUE);
+            filter.setPriority(Integer.MAX_VALUE);
             filter.addAction(Intent.ACTION_MEDIA_BUTTON);
             mRemoteControlClientReceiver = new RemoteControlClientReceiver();
             registerReceiver(mRemoteControlClientReceiver, filter);
@@ -310,7 +309,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
     public int onStartCommand(Intent intent, int flags, int startId) {
         if (intent == null)
             return START_STICKY;
-        String action = intent.getAction();
+        final String action = intent.getAction();
         if (Intent.ACTION_MEDIA_BUTTON.equals(action)) {
             MediaButtonReceiver.handleIntent(mMediaSession, intent);
             return START_STICKY;
@@ -440,8 +439,8 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         private boolean wasPlaying = false;
         @Override
         public void onReceive(Context context, Intent intent) {
-            String action = intent.getAction();
-            int state = intent.getIntExtra("state", 0);
+            final String action = intent.getAction();
+            final int state = intent.getIntExtra("state", 0);
             if( mMediaPlayer == null ) {
                 Log.w(TAG, "Intent received, but VLC is not loaded, skipping.");
                 return;
@@ -588,6 +587,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         public void onEvent(MediaPlayer.Event event) {
             switch (event.type) {
                 case MediaPlayer.Event.Playing:
+                    mMedialibrary.pauseBackgroundOperations();
                     mStopped = false;
                     loadMediaMeta();
                     if (mSavedTime > 0L) {
@@ -615,6 +615,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
                         mMedialibrary.addToHistory(getCurrentMediaLocation(), getCurrentMediaWrapper().getTitle());
                     break;
                 case MediaPlayer.Event.Paused:
+                    mMedialibrary.resumeBackgroundOperations();
                     mStopped = false;
                     Log.i(TAG, "MediaPlayer.Event.Paused");
                     executeUpdate();
@@ -626,6 +627,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
                         mWakeLock.release();
                     break;
                 case MediaPlayer.Event.Stopped:
+                    mMedialibrary.resumeBackgroundOperations();
                     Log.i(TAG, "MediaPlayer.Event.Stopped");
                     onPlaybackStopped();
                     break;
@@ -798,7 +800,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
 
     @MainThread
     public boolean switchToVideo() {
-        MediaWrapper media = mMediaList.getMedia(mCurrentIndex);
+        final MediaWrapper media = mMediaList.getMedia(mCurrentIndex);
         if (media == null || media.hasFlag(MediaWrapper.MEDIA_FORCE_AUDIO) || !canSwitchToVideo())
             return false;
         mVideoBackground = false;
@@ -853,10 +855,10 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         return isValidIndex(mCurrentIndex);
     }
 
-    private final Handler mHandler = new AudioServiceHandler(this);
+    private final Handler mHandler = new PlaybackServiceHandler(this);
 
-    private static class AudioServiceHandler extends WeakHandler<PlaybackService> {
-        public AudioServiceHandler(PlaybackService fragment) {
+    private static class PlaybackServiceHandler extends WeakHandler<PlaybackService> {
+        PlaybackServiceHandler(PlaybackService fragment) {
             super(fragment);
         }
 
@@ -912,12 +914,12 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
                                     mUpdateMeta.wait();
                             } catch (InterruptedException ignored) {}
                             final MediaMetadataCompat metaData = mMediaSession.getController().getMetadata();
-                            title = metaData.getString(MediaMetadataCompat.METADATA_KEY_TITLE);
-                            artist = metaData.getString(MediaMetadataCompat.METADATA_KEY_ALBUM_ARTIST);
-                            album = metaData.getString(MediaMetadataCompat.METADATA_KEY_ALBUM);
-                            cover = coverOnLockscreen ?
-                                    metaData.getBitmap(MediaMetadataCompat.METADATA_KEY_ALBUM_ART) :
-                                    AudioUtil.readCoverBitmap(Uri.decode(mw.getArtworkMrl()), width);
+                            title = metaData == null ? mw.getTitle() : metaData.getString(MediaMetadataCompat.METADATA_KEY_TITLE);
+                            artist = metaData == null ? mw.getArtist() : metaData.getString(MediaMetadataCompat.METADATA_KEY_ALBUM_ARTIST);
+                            album = metaData == null ? mw.getAlbum() : metaData.getString(MediaMetadataCompat.METADATA_KEY_ALBUM);
+                            cover = coverOnLockscreen && metaData != null
+                                    ? metaData.getBitmap(MediaMetadataCompat.METADATA_KEY_ALBUM_ART)
+                                    : AudioUtil.readCoverBitmap(Uri.decode(mw.getArtworkMrl()), width);
                         }
                         if (cover == null || cover.isRecycled())
                             cover = BitmapFactory.decodeResource(ctx.getResources(), R.drawable.ic_no_media);
@@ -2467,12 +2469,12 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
     @MainThread
     public int expand(boolean updateHistory) {
         final Media media = mMediaPlayer.getMedia();
-        String mrl = updateHistory ? getCurrentMediaLocation() : null;
+        final String mrl = updateHistory ? getCurrentMediaLocation() : null;
         if (media == null)
             return -1;
         final MediaList ml = media.subItems();
         media.release();
-        int ret;
+        int ret = -1;
 
         if (ml.getCount() > 0) {
             mMediaList.remove(mCurrentIndex);
@@ -2484,9 +2486,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
             }
             if (updateHistory && ml.getCount() == 1)
                 mMedialibrary.addToHistory(mrl, mMediaList.getMedia(mCurrentIndex).getTitle());
-            ret = 0;
-        } else {
-            ret = -1;
+            ret = mCurrentIndex;
         }
         ml.release();
         return ret;
@@ -2494,6 +2494,8 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
 
     public void restartMediaPlayer() {
         mMediaPlayer.setEventListener(null);
+        if (isVideoPlaying())
+            mMediaPlayer.getVLCVout().detachViews();
         final MediaPlayer mp = mMediaPlayer;
         VLCApplication.runBackground(new Runnable() {
             @Override
@@ -2502,7 +2504,6 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
             }
         });
         mMediaPlayer = newMediaPlayer();
-        /* TODO RESUME */
     }
 
     public static class Client {
