@@ -22,12 +22,10 @@ package org.videolan.vlc.gui.tv;
 
 import android.annotation.TargetApi;
 import android.app.Activity;
-import android.app.FragmentManager;
 import android.content.BroadcastReceiver;
 import android.content.Context;
 import android.content.Intent;
 import android.content.IntentFilter;
-import android.content.pm.PackageManager;
 import android.graphics.Bitmap;
 import android.net.Uri;
 import android.os.AsyncTask;
@@ -37,6 +35,7 @@ import android.os.Handler;
 import android.os.Message;
 import android.support.v17.leanback.app.BackgroundManager;
 import android.support.v17.leanback.app.BrowseFragment;
+import android.support.v17.leanback.app.BrowseSupportFragment;
 import android.support.v17.leanback.widget.ArrayObjectAdapter;
 import android.support.v17.leanback.widget.HeaderItem;
 import android.support.v17.leanback.widget.ListRow;
@@ -61,7 +60,7 @@ import org.videolan.medialibrary.Tools;
 import org.videolan.medialibrary.interfaces.MediaUpdatedCb;
 import org.videolan.medialibrary.media.MediaWrapper;
 import org.videolan.vlc.BuildConfig;
-import org.videolan.vlc.MediaParsingService;
+import org.videolan.vlc.ExternalMonitor;
 import org.videolan.vlc.PlaybackService;
 import org.videolan.vlc.R;
 import org.videolan.vlc.RecommendationsService;
@@ -107,7 +106,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
 
     public static final String TAG = "VLC/MainTvActivity";
 
-    protected BrowseFragment mBrowseFragment;
+    protected BrowseSupportFragment mBrowseFragment;
     private ProgressBar mProgressBar;
     private ArrayObjectAdapter mRowsAdapter = null;
     private ArrayObjectAdapter mVideoAdapter, mCategoriesAdapter, mHistoryAdapter, mBrowserAdapter, mOtherAdapter;
@@ -129,13 +128,20 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
             return;
         }
 
-        Permissions.checkReadStoragePermission(this, false);
+        // Delay access permission dialog prompt to avoid background corruption
+        if (!Permissions.canReadStorage())
+            mHandler.postDelayed(new Runnable() {
+                @Override
+                public void run() {
+                    Permissions.checkReadStoragePermission(MainTvActivity.this, false);
+                }
+            }, 1000);
 
         mContext = this;
         setContentView(R.layout.tv_main);
 
-        final FragmentManager fragmentManager = getFragmentManager();
-        mBrowseFragment = (BrowseFragment) fragmentManager.findFragmentById(
+        final android.support.v4.app.FragmentManager fragmentManager = getSupportFragmentManager();
+        mBrowseFragment = (BrowseSupportFragment) fragmentManager.findFragmentById(
                 R.id.browse_fragment);
         mProgressBar = findViewById(R.id.tv_main_progress);
 
@@ -144,10 +150,6 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         mBrowseFragment.setTitle(getString(R.string.app_name));
         mBrowseFragment.setBadgeDrawable(ContextCompat.getDrawable(this, R.drawable.icon));
 
-        // add a listener for selected items
-        mBrowseFragment.setOnItemViewClickedListener(this);
-        mBrowseFragment.setOnItemViewSelectedListener(this);
-
         //Enable search feature only if we detect Google Play Services.
         if (AndroidDevices.hasPlayServices) {
             mBrowseFragment.setOnSearchClickedListener(this);
@@ -178,7 +180,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
                     @Override
                     public void run() {
                         final MediaWrapper[] history = mMediaLibrary.lastMediaPlayed();
-                        mHandler.post(new Runnable() {
+                        VLCApplication.runOnMainThread(new Runnable() {
                             @Override
                             public void run() {
                                 updateHistory(history);
@@ -200,6 +202,8 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
     @Override
     protected void onStart() {
         super.onStart();
+        if (!mBackgroundManager.isAttached())
+            mBackgroundManager.attach(getWindow());
         if (mSelectedItem != null)
             TvUtil.updateBackground(mBackgroundManager, mSelectedItem);
     }
@@ -207,11 +211,9 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
     @Override
     protected void onStop() {
         super.onStop();
-        if (AndroidDevices.isAndroidTv) {
-            Intent recommendationIntent = new Intent(this,
-                    RecommendationsService.class);
-            startService(recommendationIntent);
-        }
+        if (AndroidDevices.isAndroidTv)
+            startService(new Intent(this, RecommendationsService.class));
+        TvUtil.releaseBackgroundManager(mBackgroundManager);
     }
 
     @Override
@@ -219,12 +221,10 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         super.onResume();
         if (mService != null)
             mService.addCallback(this);
-        if (mMediaLibrary.isInitiated()) {
+        if (mMediaLibrary.isInitiated())
             setmedialibraryListeners();
-        } else
+        else
             setupMediaLibraryReceiver();
-        if (!mBackgroundManager.isAttached())
-            mBackgroundManager.attach(getWindow());
     }
 
     @Override
@@ -235,28 +235,6 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         if (mService != null)
             mService.removeCallback(this);
         mMediaLibrary.removeMediaUpdatedCb();
-        TvUtil.releaseBackgroundManager(mBackgroundManager);
-    }
-
-    @Override
-    public void onRequestPermissionsResult(int requestCode,
-                                           String permissions[], int[] grantResults) {
-        switch (requestCode) {
-            case Permissions.PERMISSION_STORAGE_TAG: {
-                // If request is cancelled, the result arrays are empty.
-                if (grantResults.length > 0
-                        && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
-                    Intent serviceIntent = new Intent(MediaParsingService.ACTION_INIT, null, this, MediaParsingService.class);
-                    serviceIntent.putExtra(StartActivity.EXTRA_FIRST_RUN, getIntent().getBooleanExtra(StartActivity.EXTRA_FIRST_RUN, false));
-                    serviceIntent.putExtra(StartActivity.EXTRA_UPGRADE, getIntent().getBooleanExtra(StartActivity.EXTRA_UPGRADE, false));
-                    startService(serviceIntent);
-                } else {
-                    Permissions.showStoragePermissionDialog(this, false);
-                }
-            }
-            // other 'case' lines to check for other
-            // permissions this app might request
-        }
     }
 
     @Override
@@ -285,7 +263,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
             MediaWrapper media = (MediaWrapper) mSelectedItem;
             if (media.getType() != MediaWrapper.TYPE_DIR)
                 return false;
-            Intent intent = new Intent(this,
+            final Intent intent = new Intent(this,
                     DetailsActivity.class);
             // pass the item information
             intent.putExtra("media", (MediaWrapper) mSelectedItem);
@@ -378,6 +356,12 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         mHandler.sendEmptyMessageDelayed(SHOW_LOADING, 300);
     }
 
+    @Override
+    protected void onParsingServiceProgress() {
+        if (mProgressBar.getVisibility() == View.GONE)
+            mHandler.sendEmptyMessage(SHOW_LOADING);
+    }
+
     @Override
     protected void onParsingServiceFinished() {
         update();
@@ -491,6 +475,10 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
             mRowsAdapter.add(new ListRow(miscHeader, mOtherAdapter));
             mBrowseFragment.setAdapter(mRowsAdapter);
             mBrowseFragment.setSelectedPosition(Math.min(mBrowseFragment.getSelectedPosition(), mRowsAdapter.size()-1));
+
+            // add a listener for selected items
+            mBrowseFragment.setOnItemViewClickedListener(MainTvActivity.this);
+            mBrowseFragment.setOnItemViewSelectedListener(MainTvActivity.this);
         }
     }
 
@@ -518,7 +506,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         for (MediaWrapper directory : directories)
             mBrowserAdapter.add(new CardPresenter.SimpleCard(HEADER_DIRECTORIES, directory.getTitle(), R.drawable.ic_menu_folder_big, directory.getUri()));
 
-        if (AndroidDevices.hasLANConnection()) {
+        if (ExternalMonitor.isLan()) {
             final ArrayList<MediaWrapper> favs = MediaDatabase.getInstance().getAllNetworkFav();
             mBrowserAdapter.add(new CardPresenter.SimpleCard(HEADER_NETWORK, getString(R.string.network_browsing), R.drawable.ic_menu_network_big));
             mBrowserAdapter.add(new CardPresenter.SimpleCard(HEADER_STREAM, getString(R.string.open_mrl), R.drawable.ic_menu_stream_big));
@@ -538,7 +526,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
     }
 
     @Override
-    protected void onNetworkUpdated() {
+    public void onNetworkConnectionChanged(boolean connected) {
         updateBrowsers();
     }
 
@@ -547,8 +535,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
 
     @Override
     public
-    void onMediaEvent(Media.Event event) {
-    }
+    void onMediaEvent(Media.Event event) {}
 
     @Override
     public
