@@ -22,11 +22,13 @@ package org.videolan.vlc.gui.view;
 
 import android.content.Context;
 import android.graphics.Bitmap;
+import android.net.Uri;
 import android.util.AttributeSet;
 import android.view.LayoutInflater;
 
 import org.videolan.vlc.PlaybackService;
 import org.videolan.vlc.VLCApplication;
+import org.videolan.vlc.gui.helpers.AudioUtil;
 
 
 public abstract class AudioMediaSwitcher extends FlingViewGroup {
@@ -43,10 +45,15 @@ public abstract class AudioMediaSwitcher extends FlingViewGroup {
     }
 
     public void updateMedia(final PlaybackService service) {
+        final String artMrl = service.getCoverArt();
+        final String prevArtMrl = service.getPrevCoverArt();
+        final String nextArtMrl = service.getNextCoverArt();
         VLCApplication.runBackground(new Runnable() {
             @Override
             public void run() {
-                final Bitmap coverPrev = service.getCoverPrev(), coverCurrent = service.getCover(), coverNext = service.getCoverNext();
+                final Bitmap coverCurrent = AudioUtil.readCoverBitmap(Uri.decode(artMrl), 512);
+                final Bitmap coverPrev = AudioUtil.readCoverBitmap(Uri.decode(prevArtMrl), 512);
+                final Bitmap coverNext = AudioUtil.readCoverBitmap(Uri.decode(nextArtMrl), 512);
                 VLCApplication.runOnMainThread(new Runnable() {
                     @Override
                     public void run() {
