@@ -24,10 +24,6 @@ import android.annotation.TargetApi;
 import android.content.ComponentName;
 import android.content.Context;
 import android.content.pm.PackageManager;
-import android.net.ConnectivityManager;
-import android.net.Network;
-import android.net.NetworkCapabilities;
-import android.net.NetworkInfo;
 import android.os.Build;
 import android.os.Build.VERSION_CODES;
 import android.os.Environment;
@@ -46,11 +42,8 @@ import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileReader;
 import java.io.IOException;
-import java.net.NetworkInterface;
-import java.net.SocketException;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Enumeration;
 import java.util.HashSet;
 import java.util.LinkedList;
 import java.util.List;
@@ -72,7 +65,7 @@ public class AndroidDevices {
     public final static boolean showInternalStorage = !TextUtils.equals(Build.BRAND, "Swisscom") && !TextUtils.equals(Build.BOARD, "sprint");
     private final static String[] noMediaStyleManufacturers = {"huawei", "symphony teleca"};
     public final static boolean showMediaStyle = !isManufacturerBannedForMediastyleNotifications();
-    public static final boolean hasPlayServices = hasPlayServices();
+    public static final boolean hasPlayServices;
 
     //Devices mountpoints management
     private static final List<String> typeWL = Arrays.asList("vfat", "exfat", "sdcardfs", "fuse", "ntfs", "fat32", "ext3", "ext4", "esdfs");
@@ -99,16 +92,17 @@ public class AndroidDevices {
 
     static {
         final HashSet<String> devicesWithoutNavBar = new HashSet<>();
-        final Context ctx = VLCApplication.getAppContext();
         devicesWithoutNavBar.add("HTC One V");
         devicesWithoutNavBar.add("HTC One S");
         devicesWithoutNavBar.add("HTC One X");
         devicesWithoutNavBar.add("HTC One XL");
         hasNavBar = AndroidUtil.isICSOrLater && !devicesWithoutNavBar.contains(android.os.Build.MODEL);
+        final Context ctx = VLCApplication.getAppContext();
         final PackageManager pm = ctx.getPackageManager();
-        hasTsp = pm.hasSystemFeature("android.hardware.touchscreen");
-        isAndroidTv = pm.hasSystemFeature("android.software.leanback");
-        isChromeBook = pm.hasSystemFeature("org.chromium.arc.device_management");
+        hasTsp = pm == null || pm.hasSystemFeature("android.hardware.touchscreen");
+        isAndroidTv = pm != null && pm.hasSystemFeature("android.software.leanback");
+        isChromeBook = pm != null && pm.hasSystemFeature("org.chromium.arc.device_management");
+        hasPlayServices = pm == null || hasPlayServices(pm);
         hasPiP = AndroidUtil.isOOrLater || AndroidUtil.isNougatOrLater && isAndroidTv;
         isPhone = ((TelephonyManager) ctx.getSystemService(Context.TELEPHONY_SERVICE))
                 .getPhoneType() != TelephonyManager.PHONE_TYPE_NONE;
@@ -134,10 +128,10 @@ public class AndroidDevices {
             String line;
             while ((line = bufReader.readLine()) != null) {
 
-                StringTokenizer tokens = new StringTokenizer(line, " ");
-                String device = tokens.nextToken();
-                String mountpoint = tokens.nextToken();
-                String type = tokens.nextToken();
+                final StringTokenizer tokens = new StringTokenizer(line, " ");
+                final String device = tokens.nextToken();
+                final String mountpoint = tokens.nextToken();
+                final String type = tokens.nextToken();
 
                 // skip if already in list or if type/mountpoint is blacklisted
                 if (list.contains(mountpoint) || typeBL.contains(type) || Strings.startsWith(mountBL, mountpoint))
@@ -183,8 +177,7 @@ public class AndroidDevices {
     }
 
     @TargetApi(VERSION_CODES.HONEYCOMB_MR1)
-    public static float getCenteredAxis(MotionEvent event,
-                                        InputDevice device, int axis) {
+    public static float getCenteredAxis(MotionEvent event, InputDevice device, int axis) {
         final InputDevice.MotionRange range =
                 device.getMotionRange(axis, event.getSource());
 
@@ -204,67 +197,6 @@ public class AndroidDevices {
         return 0;
     }
 
-    public static boolean isVPNActive() {
-        if (AndroidUtil.isLolliPopOrLater) {
-            final ConnectivityManager cm = (ConnectivityManager)VLCApplication.getAppContext().getSystemService(Context.CONNECTIVITY_SERVICE);
-
-            for (Network network : cm.getAllNetworks()) {
-                if (cm.getNetworkCapabilities(network).hasTransport(NetworkCapabilities.TRANSPORT_VPN))
-                    return true;
-            }
-            return false;
-        } else {
-            try {
-                final Enumeration<NetworkInterface> networkInterfaces = NetworkInterface.getNetworkInterfaces();
-                while (networkInterfaces.hasMoreElements()) {
-                    final NetworkInterface networkInterface = networkInterfaces.nextElement();
-                    final String name = networkInterface.getDisplayName();
-                    if (name.startsWith("ppp") || name.startsWith("tun") || name.startsWith("tap"))
-                        return true;
-                }
-            } catch (SocketException ignored) {}
-            return false;
-        }
-    }
-
-    public static boolean hasLANConnection() {
-        boolean networkEnabled = false;
-        final ConnectivityManager connectivity = (ConnectivityManager) (VLCApplication.getAppContext().getSystemService(Context.CONNECTIVITY_SERVICE));
-        if (connectivity != null) {
-            final NetworkInfo networkInfo = connectivity.getActiveNetworkInfo();
-            if (networkInfo != null && networkInfo.isConnected() &&
-                    (networkInfo.getType() != ConnectivityManager.TYPE_MOBILE)) {
-                networkEnabled = true;
-            }
-        }
-        return networkEnabled;
-    }
-
-    public static boolean hasConnection() {
-        boolean networkEnabled = false;
-        final ConnectivityManager connectivity = (ConnectivityManager) (VLCApplication.getAppContext().getSystemService(Context.CONNECTIVITY_SERVICE));
-        if (connectivity != null) {
-            final NetworkInfo networkInfo = connectivity.getActiveNetworkInfo();
-            if (networkInfo != null && networkInfo.isConnected()) {
-                networkEnabled = true;
-            }
-        }
-        return networkEnabled;
-    }
-
-    public static boolean hasMobileConnection() {
-        boolean networkEnabled = false;
-        final ConnectivityManager connectivity = (ConnectivityManager) (VLCApplication.getAppContext().getSystemService(Context.CONNECTIVITY_SERVICE));
-        if (connectivity != null) {
-            final NetworkInfo networkInfo = connectivity.getActiveNetworkInfo();
-            if (networkInfo != null && networkInfo.isConnected() &&
-                    (networkInfo.getType() == ConnectivityManager.TYPE_MOBILE)) {
-                networkEnabled = true;
-            }
-        }
-        return networkEnabled;
-    }
-
     public static void setRemoteControlReceiverEnabled(boolean enabled) {
         VLCApplication.getAppContext().getPackageManager().setComponentEnabledSetting(
                 new ComponentName(VLCApplication.getAppContext(), RemoteControlClientReceiver.class),
@@ -280,9 +212,9 @@ public class AndroidDevices {
         return false;
     }
 
-    private static boolean hasPlayServices() {
+    private static boolean hasPlayServices(PackageManager pm) {
         try {
-            VLCApplication.getAppContext().getPackageManager().getPackageInfo("com.google.android.gsf", PackageManager.GET_SERVICES);
+            pm.getPackageInfo("com.google.android.gsf", PackageManager.GET_SERVICES);
             return true;
         } catch (PackageManager.NameNotFoundException ignored) {}
         return false;
