@@ -113,8 +113,6 @@ public class HttpImageLoader implements Callbacks {
             return icon;
         try {
             URL url = new URL(imageUrl);
-            if (url.getPort() <= 0)
-                return null;
             urlConnection = (HttpURLConnection) url.openConnection();
             InputStream in = new BufferedInputStream(urlConnection.getInputStream());
             icon = BitmapFactory.decodeStream(in);
